@@ -110,7 +110,7 @@ class AISyntheticGenerator:
         self.model.summary()
         return self.model
 
-    def PrepareTrainingData(self, root, subjects, scanners, sets, targetSeries, dataManager=None, simpleITKRunner=None, batch_size=5000, fetchFromAzure=True):
+    def PrepareTrainingData(self, root, subjects, scanners, sets, targetSeries, dataManager=None, simpleITKRunner=None, batch_size=5000, fetchFromAzure=True, flipTargetSeries=False):
         T1_lin = []; T2_lin = []; M0_lin = []; target_lin = []
         if(dataManager == None):
             print("Data Manager object not set.")
@@ -124,6 +124,8 @@ class AISyntheticGenerator:
                         else:
                             (T1, T2, M0) = dataManager.loadMRFSeries(subject, scanner, set)
                             target = dataManager.loadSingleSeries(subject, scanner, set, targetSeries)
+                        if(flipTargetSeries):
+                            target = target[::-1, :, :]
                         if(simpleITKRunner is not None):
                             if(self.referenceBlochGenerator is not None):
                                 referenceSynthetic = self.referenceBlochGenerator.generateSynthetics(T1, T2, M0)
